/*********************************************************************************

Copyright(c) 2012 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*!
 * @file      MemCopyListMode.h
 * @brief     Example to demonstrate memory copy using list mode.
 * @version:  $Revision: 17899 $
 * @date:     $Date: 2014-06-05 10:05:00 -0400 (Thu, 05 Jun 2014) $
 *
 * @details
 *            This is the primary include file for memory copy example using DMA list mode.
 *
 */
#ifndef _MMEMCOPY_H_
#define _MMEMCOPY_H_
/*=============  I N C L U D E S   =============*/

/* ADSP-BF608/609 */
#if defined(__ADSPBF609_FAMILY__)
/* SEC includes */
#include <services/int/adi_sec.h>
#endif /* __ADSPBF609_FAMILY__ */

/* DMA Manager includes */
#include <services/dma/adi_dma.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/*=============   F U N C T I O N S  =============*/
void MDMAprep (void);
ADI_DMA_RESULT StartOneShotTransmission(ADI_DMA_STREAM_ID id, void * dest, void * src);


/*=============  D E F I N E S  =============*/

/* Enable macro to call soft switch config API */
//#define __HAS_SOFT_CONFIG__

/* Enable macro to build example in callback mode */
#define MEMCOPY_ENABLE_CALLBACK

/* Enable macro to display debug information */
#define ENABLE_DEBUG_INFO

/* Buffer size in bytes used for memory copy */
#define MY_IMG_BUF_SIZE         	(512u*512u)
#define MY_IMG_BLK_SIZE         	(512u*8u)

/* Number of List Descriptors to use */
#define MEMCOPY_NUM_DESC            (MY_IMG_BUF_SIZE/MY_IMG_BLK_SIZE)

/* Number of bytes to copy per descriptor */
#define MEMCOPY_BYTES_PER_DESC      MY_IMG_BLK_SIZE

/*
 * Word/Memory transfer size to use for this example
 * Enable only one word transfer size
 */
//#define MEMCOPY_XFER_1BYTE        /* Enable macro for 1 byte transfer */
//#define MEMCOPY_XFER_2BYTES       /* Enable macro for 2 bytes transfer */
#define MEMCOPY_XFER_4BYTES       /* Enable macro for 4 bytes transfer */

/* Word/Memory transfer size in bytes */
#if defined (MEMCOPY_XFER_4BYTES)   /* 4 bytes transfer */
#define MEMCOPY_MSIZE               ADI_DMA_MSIZE_4BYTES
#define MEMCOPY_MSIZE_IN_BYTES      (4u)
#elif defined (MEMCOPY_XFER_2BYTES) /* 2 bytes transfer */
#define MEMCOPY_MSIZE               ADI_DMA_MSIZE_2BYTES
#define MEMCOPY_MSIZE_IN_BYTES      (2u)
#else                               /* 1 byte transfer */
#define MEMCOPY_MSIZE               ADI_DMA_MSIZE_1BYTE
#define MEMCOPY_MSIZE_IN_BYTES      (1u)
#endif

/* Memory Copy time out value */
#define MEMCOPY_TIME_OUT_VAL        (0x7FFFFFFu)


/* ADSP-BF70x */
#define MEMCOPY_STREAM_ID           ADI_DMA_MEMDMA_S0       /* Stream 0 */


/* IF (Debug info enabled) */
#if defined(ENABLE_DEBUG_INFO)
#define DEBUG_MSG1(message)     printf(message)
#define DEBUG_MSG2(message, result) \
    do { \
        printf(message); \
        if(result) \
        { \
            printf(", Error Code: 0x%08X", eResult); \
            printf("\n"); \
        } \
    } while (0)
/* ELSE (Debug info disabled) */
#else
#define DEBUG_MSG1(message)
#define DEBUG_MSG2(message, result)
#endif

#endif //_MMEMCOPY_H_

/*****/
